@@ -170,6 +170,9 @@ ApvlvView::widget ()
 ApvlvWindow *
 ApvlvView::currentWindow ()
 {
+  if (mCurrTabPos == -1)
+    return nullptr;
+
   return mTabList[mCurrTabPos].mRootWindow->activeCoreWindow ();
 }
 
@@ -746,6 +749,10 @@ ApvlvView::fullscreen ()
 {
   if (mHasFull == false)
     {
+      ApvlvCore *core = crtadoc ();
+      if (core)
+        core->toggleContent (false);
+
       gtk_window_fullscreen (GTK_WINDOW (mMainWindow));
       mHasFull = true;
     }
@@ -759,7 +766,11 @@ ApvlvView::fullscreen ()
 ApvlvCore *
 ApvlvView::crtadoc ()
 {
-  return currentWindow ()->getCore ();
+  ApvlvWindow *curwin = currentWindow ();
+  if (curwin == nullptr)
+    return nullptr;
+
+  return curwin->getCore ();
 }
 
 returnType
@@ -770,6 +781,10 @@ ApvlvView::subprocess (int ct, guint key)
   mProCmdCnt = 0;
   switch (procmd)
     {
+    case 'Z':
+      if (key == 'Z')
+        quit ();
+
     case CTRL ('w'):
       if (key == 'q' || key == CTRL ('Q'))
         {
@@ -835,6 +850,10 @@ ApvlvView::process (int has, int ct, guint key)
 
   switch (key)
     {
+    case 'Z':
+      mProCmd = 'Z';
+      return NEED_MORE;
+
     case CTRL ('w'):
       mProCmd = CTRL ('w');
       mProCmdCnt = has ? ct : 1;
